"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("../");
const units_EN_json_1 = __importDefault(require("../../nlp/units_EN.json"));
const units_FR_json_1 = __importDefault(require("../../nlp/units_FR.json"));
const keys_1 = require("./keys");
class ConversionsUtils {
    /**
     * Returns a list of units for the configured language.
     */
    static getUnits(lang) {
        switch (lang) {
            case __1.LANGUAGES.EN:
                return units_EN_json_1.default;
            case __1.LANGUAGES.FR:
                return units_FR_json_1.default;
        }
    }
    /**
     * Returns the key who has match the result
     */
    static getUnitKey(unit) {
        let returnUnit = unit;
        for (let i = 0; i < Object.keys(keys_1.globalUnit).length; i++) {
            if (Object.values(keys_1.globalUnit)[i].includes(unit)) {
                returnUnit = Object.keys(keys_1.globalUnit)[i];
                i = Object.keys(keys_1.globalUnit).length;
            }
        }
        return returnUnit;
    }
    /**
     * Normalizes a given amount.
     * @param val The amount to be normalized.
     */
    static normalizeAmount(lang, val) {
        let out;
        // Normalizing numeric word to number
        if (this.getUnits(lang).wordNumbers.hasOwnProperty(val)) {
            out = this.getUnits(lang).wordNumbers[val];
        }
        //  Normalizing and multiply word and number amounts (3 demi oeufs, 3 demi poulet, ...)
        const mutlipleRec = /(\d+) (\w*)/gim;
        const matchesMultiple = mutlipleRec.exec(String(val));
        if (matchesMultiple) {
            if (matchesMultiple[1] &&
                matchesMultiple[2] &&
                this.getUnits(lang).wordNumbers.hasOwnProperty(matchesMultiple[2])) {
                out =
                    Number(matchesMultiple[1]) *
                        this.getUnits(lang).wordNumbers[matchesMultiple[2]];
            }
        }
        // Summing up average amounts (2-3 oeufs, 4-5 grammes, ...)
        const averageRec = /(\d)?\-(\d)/gim;
        const matchesAverage = averageRec.exec(String(val));
        if (matchesAverage) {
            if (matchesAverage[1] && matchesAverage[2]) {
                out = (Number(matchesAverage[1]) + Number(matchesAverage[2])) / 2;
            }
        }
        // Summing up mixed amounts (integer and fractions)
        const fractionRe = /(\d+)?(.*)?(\d)\/(\d)/gim;
        const matches = fractionRe.exec(String(val));
        if (matches) {
            if (matches[1] && matches[3] && matches[4]) {
                out = (Number(matches[1]) * Number(matches[3])) / Number(matches[4]);
            }
            else {
                out = Number(matches[3]) / Number(matches[4]);
            }
        }
        if (!out) {
            out = Number(val);
        }
        return out;
    }
}
exports.default = ConversionsUtils;
